@@ -19,7 +19,7 @@ transform_utf8 <- function(path, fun, dry) {
 #'   styling are not identical.
 #' @keywords internal
 transform_utf8_one <- function(path, fun, dry) {
-  rlang::arg_match(dry, c("on", "off", "fail"))
+  rlang::arg_match0(dry, c("on", "off", "fail"))
   rlang::try_fetch(
     {
       file_with_info <- read_utf8(path)
@@ -31,30 +31,30 @@ transform_utf8_one <- function(path, fun, dry) {
       identical_content <- identical(file_with_info$text, new)
       identical <- identical_content && !file_with_info$missing_EOF_line_break
       if (!identical) {
-        if (dry == "fail") {
-          rlang::abort(
+        switch(dry,
+          fail = rlang::abort(
             paste0(
               "File `", path, "` would be modified by styler and argument dry",
               " is set to 'fail'."
             ),
             class = "dryError"
-          )
-        } else if (dry == "on") {
-          # don't do anything
-        } else if (dry == "off") {
-          write_utf8(new, path)
-        } else {
-          # not implemented
-        }
+          ),
+          on = {
+            # don't do anything
+          },
+          off = write_utf8(new, path),
+          {
+            # not implemented
+          }
+        )
       }
       !identical
     },
     error = function(e) {
       if (inherits(e, "dryError")) {
         rlang::abort(conditionMessage(e))
-      } else {
-        warn(paste0("When processing ", path, ": ", conditionMessage(e)))
       }
+      warn(paste0("When processing ", path, ": ", conditionMessage(e)))
       NA
     }
   )
@@ -103,7 +103,8 @@ read_utf8_bare <- function(con, warn = TRUE) {
         "The file ", con, " is not encoded in UTF-8. ",
         "These lines contain invalid UTF-8 characters: "
       ),
-      toString(c(utils::head(i), if (n > 6L) "..."))
+      toString(c(utils::head(i), if (n > 6L) "...")),
+      call. = FALSE
     )
   }
   x
