@@ -5,3 +5,14 @@ c() %>%
                                  g_out()
 
 a <- function(jon_the_pipe) {}
+
+x %>%
+
+  # break
+  call()
+
+
+y %>%
+
+
+  call() # mor
