@@ -33,9 +33,9 @@ create_style_guide <- function(initialize = default_style_guide_attributes,
                                indention = NULL,
                                use_raw_indention = FALSE,
                                reindention = tidyverse_reindention()) {
-  lst(
+  list(
     # transformer functions
-    initialize = lst(initialize),
+    initialize = list(initialize),
     line_break,
     space,
     token,
