@@ -1,27 +1,26 @@
-
 #' Create a style guide
 #'
 #' @param reindention A list of parameters for regex re-indention, most
 #'   conveniently constructed using [specify_reindention()].
 #' @examples
 #' # empty
-#' 
-#' 
+#'
+#'
 #' # two
-#' 
-#' 
-#' 
-#' 
+#'
+#'
+#'
+#'
 #' # more
 #' a <- 3
 #' # a comment
 #' \dontrun{
 #' x
-#' 
+#'
 #' y # hi
-#' 
+#'
 #' # more
-#' 
+#'
 #' a <- 3
 #' }
 #' @importFrom purrr compact
@@ -33,9 +32,9 @@ create_style_guide <- function(initialize = default_style_guide_attributes,
                                indention = NULL,
                                use_raw_indention = FALSE,
                                reindention = tidyverse_reindention()) {
-  lst(
+  list(
     # transformer functions
-    initialize = lst(initialize),
+    initialize = list(initialize),
     line_break,
     space,
     token,
