@@ -12,3 +12,7 @@ a[2 ]
 a[ 2]
 
 a[ 2 ]
+
+
+a [[2]]
+a [1]
